PyXMake Developer Guide: PyXMake.VTL.ssh_make Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.ssh_make Namespace Reference

## Functions
def | main (BuildID, user, key, path2src=os.path.join(__mcd_core_path,"src"), path2feature=os.path.join(__mcd_core_path,"solver"), files=VTL.GetSourceCode(0), source_file="mcd_astandard.f", version="abq2019", makeopt=0, scratch=VTL.Scratch, dependency=posixpath.join(Utility.AsDrive("cluster", posixpath.sep),"software","mcodac","stable"), verbosity=0, host="129.247.54.37", port=22, kwargs)

## Variables
| parser
| metavar
| nargs
| help
| args
| BuildID = args.BuildID[0]
| user = args.user[0]
| key = args.key[0]
| path2src = args.source_path[0]
| path2feature = args.feature_path[0]

## Detailed Description

    Minimum working example for PyXMake.

    @note: Compile the complete MCODAC library for ABAQUS remotely.
    Created on 25.06.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake
          - Adopt Paths.log according to your system settings.

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

def PyXMake.VTL.ssh_make.main | ( |  | BuildID,
|  |  | user,
|  |  | key,
|  |  | path2src = `os.path.join(__mcd_core_path,"src")`,
|  |  | path2feature = `os.path.join(__mcd_core_path,"solver")`,
|  |  | files = `VTL.GetSourceCode(0)`,
|  |  | source_file = `"mcd_astandard.f"`,
|  |  | version = `"abq2019"`,
|  |  | makeopt = `0`,
|  |  | scratch = `VTL.Scratch`,
|  |  | dependency = `posixpath.join(Utility.AsDrive("cluster",posixpath.sep),"software","mcodac","stable")`,
|  |  | verbosity = `0`,
|  |  | host = `"129.247.54.37"`,
|  |  | port = `22`,
|  |  | kwargs
| ) |  |

    Main function to execute the script.

Definition at line 73 of file ssh_make.py.

## Variable Documentation

## ◆ parser

PyXMake.VTL.ssh_make.parser

Initial value:
1 = argparse.ArgumentParser(description="Build MCODAC's shared library remotely and its subsidiaries on the institute cluster.\
2 Supported features are ABAQUS, ANSYS & NASTRAN")

Definition at line 149 of file ssh_make.py.